@@ -6,8 +6,8 @@ setClass("Line",
 			stop("coords cannot contain missing values")
 		if (ncol(object@coords) != 2)
 			return("coords should have 2 columns")
-		if (nrow(object@coords) < 2)
-			return("Line should have at least 2 points")
+#		if (nrow(object@coords) < 2)
+#			return("Line should have at least 2 points")
 		return(TRUE)
 	}
 )
